@@ -1,23 +1,35 @@
+"""
+Main CLI entrypoint.
+"""
 import sys
 
 
 def print_info() -> None:
+    """
+    Print package info to stdout.
+    """
     print(
-        "Type annotations for boto3.RAM 1.17.99\n"
-        "Version:         1.17.99\n"
-        "Builder version: 4.18.4\n"
+        "Type annotations for boto3.RAM 1.17.101\n"
+        "Version:         1.17.101.post1\n"
+        "Builder version: 4.20.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-ram/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.99")
+    """
+    Print package version to stdout.
+    """
+    print("1.17.101.post1")
 
 
 def main() -> None:
+    """
+    Main CLI entrypoint.
+    """
     if "--version" in sys.argv:
         return print_version()
     print_info()
