@@ -32,30 +32,30 @@ from .paginator import (
     ListResourcesPaginator,
 )
 from .type_defs import (
-    AcceptResourceShareInvitationResponseTypeDef,
-    AssociateResourceSharePermissionResponseTypeDef,
-    AssociateResourceShareResponseTypeDef,
-    CreateResourceShareResponseTypeDef,
-    DeleteResourceShareResponseTypeDef,
-    DisassociateResourceSharePermissionResponseTypeDef,
-    DisassociateResourceShareResponseTypeDef,
-    EnableSharingWithAwsOrganizationResponseTypeDef,
-    GetPermissionResponseTypeDef,
-    GetResourcePoliciesResponseTypeDef,
-    GetResourceShareAssociationsResponseTypeDef,
-    GetResourceShareInvitationsResponseTypeDef,
-    GetResourceSharesResponseTypeDef,
-    ListPendingInvitationResourcesResponseTypeDef,
-    ListPermissionsResponseTypeDef,
-    ListPrincipalsResponseTypeDef,
-    ListResourceSharePermissionsResponseTypeDef,
-    ListResourcesResponseTypeDef,
-    ListResourceTypesResponseTypeDef,
-    PromoteResourceShareCreatedFromPolicyResponseTypeDef,
-    RejectResourceShareInvitationResponseTypeDef,
+    AcceptResourceShareInvitationResponseResponseTypeDef,
+    AssociateResourceSharePermissionResponseResponseTypeDef,
+    AssociateResourceShareResponseResponseTypeDef,
+    CreateResourceShareResponseResponseTypeDef,
+    DeleteResourceShareResponseResponseTypeDef,
+    DisassociateResourceSharePermissionResponseResponseTypeDef,
+    DisassociateResourceShareResponseResponseTypeDef,
+    EnableSharingWithAwsOrganizationResponseResponseTypeDef,
+    GetPermissionResponseResponseTypeDef,
+    GetResourcePoliciesResponseResponseTypeDef,
+    GetResourceShareAssociationsResponseResponseTypeDef,
+    GetResourceShareInvitationsResponseResponseTypeDef,
+    GetResourceSharesResponseResponseTypeDef,
+    ListPendingInvitationResourcesResponseResponseTypeDef,
+    ListPermissionsResponseResponseTypeDef,
+    ListPrincipalsResponseResponseTypeDef,
+    ListResourceSharePermissionsResponseResponseTypeDef,
+    ListResourcesResponseResponseTypeDef,
+    ListResourceTypesResponseResponseTypeDef,
+    PromoteResourceShareCreatedFromPolicyResponseResponseTypeDef,
+    RejectResourceShareInvitationResponseResponseTypeDef,
     TagFilterTypeDef,
     TagTypeDef,
-    UpdateResourceShareResponseTypeDef,
+    UpdateResourceShareResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -102,7 +102,7 @@ class Exceptions:
 
 class RAMClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html)
     """
 
@@ -111,9 +111,11 @@ class RAMClient:
 
     def accept_resource_share_invitation(
         self, *, resourceShareInvitationArn: str, clientToken: str = None
-    ) -> AcceptResourceShareInvitationResponseTypeDef:
+    ) -> AcceptResourceShareInvitationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
+        Accepts an invitation to a resource share from another AWS account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#accept_resource_share_invitation)
         """
 
@@ -124,9 +126,12 @@ class RAMClient:
         resourceArns: List[str] = None,
         principals: List[str] = None,
         clientToken: str = None
-    ) -> AssociateResourceShareResponseTypeDef:
+    ) -> AssociateResourceShareResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.associate_resource_share)
+        Associates the specified resource share with the specified principals and
+        resources.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.associate_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate_resource_share)
         """
 
@@ -138,15 +143,19 @@ class RAMClient:
         replace: bool = None,
         clientToken: str = None,
         permissionVersion: int = None
-    ) -> AssociateResourceSharePermissionResponseTypeDef:
+    ) -> AssociateResourceSharePermissionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
+        Associates a permission with a resource share.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate_resource_share_permission)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#can_paginate)
         """
 
@@ -160,17 +169,21 @@ class RAMClient:
         allowExternalPrincipals: bool = None,
         clientToken: str = None,
         permissionArns: List[str] = None
-    ) -> CreateResourceShareResponseTypeDef:
+    ) -> CreateResourceShareResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.create_resource_share)
+        Creates a resource share.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.create_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#create_resource_share)
         """
 
     def delete_resource_share(
         self, *, resourceShareArn: str, clientToken: str = None
-    ) -> DeleteResourceShareResponseTypeDef:
+    ) -> DeleteResourceShareResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.delete_resource_share)
+        Deletes the specified resource share.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.delete_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#delete_resource_share)
         """
 
@@ -181,25 +194,32 @@ class RAMClient:
         resourceArns: List[str] = None,
         principals: List[str] = None,
         clientToken: str = None
-    ) -> DisassociateResourceShareResponseTypeDef:
+    ) -> DisassociateResourceShareResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.disassociate_resource_share)
+        Disassociates the specified principals or resources from the specified resource
+        share.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.disassociate_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate_resource_share)
         """
 
     def disassociate_resource_share_permission(
         self, *, resourceShareArn: str, permissionArn: str, clientToken: str = None
-    ) -> DisassociateResourceSharePermissionResponseTypeDef:
+    ) -> DisassociateResourceSharePermissionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
+        Disassociates an AWS RAM permission from a resource share.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate_resource_share_permission)
         """
 
     def enable_sharing_with_aws_organization(
         self,
-    ) -> EnableSharingWithAwsOrganizationResponseTypeDef:
+    ) -> EnableSharingWithAwsOrganizationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
+        Enables resource sharing within your AWS Organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#enable_sharing_with_aws_organization)
         """
 
@@ -211,15 +231,19 @@ class RAMClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#generate_presigned_url)
         """
 
     def get_permission(
         self, *, permissionArn: str, permissionVersion: int = None
-    ) -> GetPermissionResponseTypeDef:
+    ) -> GetPermissionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.get_permission)
+        Gets the contents of an AWS RAM permission in JSON format.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_permission)
         """
 
@@ -230,9 +254,11 @@ class RAMClient:
         principal: str = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> GetResourcePoliciesResponseTypeDef:
+    ) -> GetResourcePoliciesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.get_resource_policies)
+        Gets the policies for the specified resources that you own and have shared.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_resource_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_policies)
         """
 
@@ -246,9 +272,11 @@ class RAMClient:
         associationStatus: ResourceShareAssociationStatusType = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> GetResourceShareAssociationsResponseTypeDef:
+    ) -> GetResourceShareAssociationsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.get_resource_share_associations)
+        Gets the resources or principals for the resource shares that you own.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_resource_share_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_share_associations)
         """
 
@@ -259,9 +287,11 @@ class RAMClient:
         resourceShareArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> GetResourceShareInvitationsResponseTypeDef:
+    ) -> GetResourceShareInvitationsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
+        Gets the invitations that you have received for resource shares.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_share_invitations)
         """
 
@@ -272,29 +302,37 @@ class RAMClient:
         resourceShareArns: List[str] = None,
         resourceShareStatus: ResourceShareStatusType = None,
         name: str = None,
-        tagFilters: List[TagFilterTypeDef] = None,
+        tagFilters: List["TagFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None,
         permissionArn: str = None
-    ) -> GetResourceSharesResponseTypeDef:
+    ) -> GetResourceSharesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.get_resource_shares)
+        Gets the resource shares that you own or the resource shares that are shared
+        with you.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.get_resource_shares)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_shares)
         """
 
     def list_pending_invitation_resources(
         self, *, resourceShareInvitationArn: str, nextToken: str = None, maxResults: int = None
-    ) -> ListPendingInvitationResourcesResponseTypeDef:
+    ) -> ListPendingInvitationResourcesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
+        Lists the resources in a resource share that is shared with you but that the
+        invitation is still pending for.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_pending_invitation_resources)
         """
 
     def list_permissions(
         self, *, resourceType: str = None, nextToken: str = None, maxResults: int = None
-    ) -> ListPermissionsResponseTypeDef:
+    ) -> ListPermissionsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.list_permissions)
+        Lists the AWS RAM permissions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_permissions)
         """
 
@@ -308,25 +346,32 @@ class RAMClient:
         resourceShareArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> ListPrincipalsResponseTypeDef:
+    ) -> ListPrincipalsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.list_principals)
+        Lists the principals that you have shared resources with or that have shared
+        resources with you.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_principals)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_principals)
         """
 
     def list_resource_share_permissions(
         self, *, resourceShareArn: str, nextToken: str = None, maxResults: int = None
-    ) -> ListResourceSharePermissionsResponseTypeDef:
+    ) -> ListResourceSharePermissionsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
+        Lists the AWS RAM permissions that are associated with a resource share.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resource_share_permissions)
         """
 
     def list_resource_types(
         self, *, nextToken: str = None, maxResults: int = None
-    ) -> ListResourceTypesResponseTypeDef:
+    ) -> ListResourceTypesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.list_resource_types)
+        Lists the shareable resource types supported by AWS RAM.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_resource_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resource_types)
         """
 
@@ -340,37 +385,50 @@ class RAMClient:
         resourceShareArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> ListResourcesResponseTypeDef:
+    ) -> ListResourcesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.list_resources)
+        Lists the resources that you added to a resource shares or the resources that
+        are shared with you.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.list_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resources)
         """
 
     def promote_resource_share_created_from_policy(
         self, *, resourceShareArn: str
-    ) -> PromoteResourceShareCreatedFromPolicyResponseTypeDef:
+    ) -> PromoteResourceShareCreatedFromPolicyResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
+        Resource shares that were created by attaching a policy to a resource are
+        visible only to the resource share owner, and the resource share cannot be
+        modified in AWS RAM.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#promote_resource_share_created_from_policy)
         """
 
     def reject_resource_share_invitation(
         self, *, resourceShareInvitationArn: str, clientToken: str = None
-    ) -> RejectResourceShareInvitationResponseTypeDef:
+    ) -> RejectResourceShareInvitationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
+        Rejects an invitation to a resource share from another AWS account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#reject_resource_share_invitation)
         """
 
     def tag_resource(self, *, resourceShareArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.tag_resource)
+        Adds the specified tags to the specified resource share that you own.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#tag_resource)
         """
 
     def untag_resource(self, *, resourceShareArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.untag_resource)
+        Removes the specified tags from the specified resource share that you own.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#untag_resource)
         """
 
@@ -381,9 +439,11 @@ class RAMClient:
         name: str = None,
         allowExternalPrincipals: bool = None,
         clientToken: str = None
-    ) -> UpdateResourceShareResponseTypeDef:
+    ) -> UpdateResourceShareResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Client.update_resource_share)
+        Updates the specified resource share that you own.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Client.update_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#update_resource_share)
         """
 
@@ -392,7 +452,8 @@ class RAMClient:
         self, operation_name: Literal["get_resource_policies"]
     ) -> GetResourcePoliciesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
         """
 
     @overload
@@ -400,7 +461,8 @@ class RAMClient:
         self, operation_name: Literal["get_resource_share_associations"]
     ) -> GetResourceShareAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
         """
 
     @overload
@@ -408,7 +470,8 @@ class RAMClient:
         self, operation_name: Literal["get_resource_share_invitations"]
     ) -> GetResourceShareInvitationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
         """
 
     @overload
@@ -416,17 +479,20 @@ class RAMClient:
         self, operation_name: Literal["get_resource_shares"]
     ) -> GetResourceSharesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourceShares)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.GetResourceShares)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_principals"]) -> ListPrincipalsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.ListPrincipals)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.ListPrincipals)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resources"]) -> ListResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.ListResources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/ram.html#RAM.Paginator.ListResources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
         """
